@@ -4,16 +4,14 @@ import os
 import json
 from threading import Thread
 from diskcache import Deque
-from hamunafs.utils.singleton_wrapper import Singleton
 
 import uuid
 
+from .singleton_wrapper import Singleton
+
 
 class MQTTClient(Singleton):
     def __init__(self, client_id, username, password, local_cache_path='../mqtt_offlines'):
-        if not self.need_init():
-            return
-
         self.connected = False
 
         self.client = mqtt.Client(client_id=client_id + str(uuid.uuid1()), clean_session=False)
@@ -29,8 +27,6 @@ class MQTTClient(Singleton):
         os.makedirs(local_cache_path, exist_ok=True)
         self.offlines = Deque(directory=local_cache_path)
 
-        self._inited = True
-
     def connect(self, host, port):
         self.thread = Thread(target=self.__mqtt_connect, args=(host, port))
         self.thread.setDaemon(True)
